@@ -1,4 +1,4 @@
-package Pcore::DBD v0.3.4;
+package Pcore::DBD v0.3.5;
 
 use Pcore -role;
 use Pcore::Util::Text qw[escape_scalar];
@@ -13,23 +13,17 @@ has dbd_type       => ( is => 'lazy', isa => Str,      init_arg => undef );
 has _builder_class => ( is => 'lazy', isa => Str,      init_arg => undef );
 has _ddl_class     => ( is => 'lazy', isa => Str,      init_arg => undef );
 
-sub _build_dbd_type {
-    my $self = shift;
-
+sub _build_dbd_type ($self) {
     ( my $type ) = ref($self) =~ /::([^:]+)\z/sm;
 
     return $type;
 }
 
-sub _build__builder_class {
-    my $self = shift;
-
+sub _build__builder_class ($self) {
     return P->class->load( $self->dbd_type, ns => 'Pcore::DBD::Builder' );
 }
 
-sub _build__ddl_class {
-    my $self = shift;
-
+sub _build__ddl_class ($self) {
     return P->class->load( $self->dbd_type, ns => 'Pcore::DBD::DDL' );
 }
 
@@ -345,9 +339,9 @@ sub ddl {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 113                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 107                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 236                  │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_default_attr' declared but not     │
+## │    3 │ 230                  │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_default_attr' declared but not     │
 ## │      │                      │ used                                                                                                           │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
